pub struct FileReader { /* private fields */ }Implementations
Sourceimpl FileReader
impl FileReader
Sourcepub fn file_length(&self) -> usize
pub fn file_length(&self) -> usize
Returns the total size of the file
Sourcepub fn remaining(&self) -> usize
pub fn remaining(&self) -> usize
Returns the remaining bytes left based on the current cursor position.
Sourcepub fn set_position(&mut self, pos: usize)
pub fn set_position(&mut self, pos: usize)
Sets the cursor to the position. Panics if the position is beyond the end of the file
Sourcepub async fn read_bytes(&mut self, len: usize) -> Result<Bytes>
pub async fn read_bytes(&mut self, len: usize) -> Result<Bytes>
Sourcepub async fn read_into(&mut self, buf: &mut [u8]) -> Result<usize>
pub async fn read_into(&mut self, buf: &mut [u8]) -> Result<usize>
Read up to buf.len() bytes into the provided slice, advancing the internal position in the file.
Returns the number of bytes that were read, or 0 if the end of the file has been reached.
Sourcepub async fn read_range(&self, offset: usize, len: usize) -> Result<Bytes>
pub async fn read_range(&self, offset: usize, len: usize) -> Result<Bytes>
Read up to len bytes starting at offset into a new Bytes object. The returned buffer
could be smaller than len if offset + len extends beyond the end of the file.
Panics if the requested range is outside of the file