pub struct ClientBuilder { /* private fields */ }Expand description
Builds a new synchronous Client instance.
Implementations
Sourceimpl ClientBuilder
impl ClientBuilder
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new ClientBuilder.
Sourcepub fn with_config(
self,
config: impl IntoIterator<Item = (impl Into<String>, impl Into<String>)>,
) -> Self
pub fn with_config( self, config: impl IntoIterator<Item = (impl Into<String>, impl Into<String>)>, ) -> Self
Set configs to use for the client.
Sourcepub fn with_config_dir(self, config_dir: impl Into<String>) -> Self
pub fn with_config_dir(self, config_dir: impl Into<String>) -> Self
Set the configuration directory path to read from.
Sourcepub fn with_user(self, user: impl Into<String>) -> Self
pub fn with_user(self, user: impl Into<String>) -> Self
Set the effective user for the client. If not set, the client will detect user from
environment variables HADOOP_USER_NAME or HADOOP_PROXY_USER.
Sourcepub fn with_kerberos_principal(self, principal: impl Into<String>) -> Self
pub fn with_kerberos_principal(self, principal: impl Into<String>) -> Self
Set the Kerberos principal used by this client.
Sourcepub fn with_kerberos_keytab(self, keytab: impl Into<String>) -> Self
pub fn with_kerberos_keytab(self, keytab: impl Into<String>) -> Self
Set the Kerberos keytab used by this client.
Sourcepub fn with_kerberos_cache(self, cache: impl Into<String>) -> Self
pub fn with_kerberos_cache(self, cache: impl Into<String>) -> Self
Set the Kerberos credential cache used by this client.