pub struct FileReader { /* private fields */ }Expand description
A blocking file reader.
Implementations
Sourceimpl FileReader
impl FileReader
Sourcepub fn file_length(&self) -> usize
pub fn file_length(&self) -> usize
Returns the total size of the file.
Sourcepub fn remaining(&self) -> usize
pub fn remaining(&self) -> usize
Returns the remaining bytes left based on the current cursor position.
Sourcepub fn set_position(&mut self, pos: usize)
pub fn set_position(&mut self, pos: usize)
Sets the cursor position.
Sourcepub fn read_bytes(&mut self, len: usize) -> Result<Bytes>
pub fn read_bytes(&mut self, len: usize) -> Result<Bytes>
Read up to len bytes, advancing the internal position.
Sourcepub fn read_into(&mut self, buf: &mut [u8]) -> Result<usize>
pub fn read_into(&mut self, buf: &mut [u8]) -> Result<usize>
Read up to buf.len() bytes into the provided slice.
Sourcepub fn read_range(&self, offset: usize, len: usize) -> Result<Bytes>
pub fn read_range(&self, offset: usize, len: usize) -> Result<Bytes>
Read up to len bytes starting at offset.
Sourcepub fn read_range_buf(&self, buf: &mut [u8], offset: usize) -> Result<()>
pub fn read_range_buf(&self, buf: &mut [u8], offset: usize) -> Result<()>
Read file data into an existing buffer.
Sourcepub fn read_range_stream(&self, offset: usize, len: usize) -> FileReadStream ⓘ
pub fn read_range_stream(&self, offset: usize, len: usize) -> FileReadStream ⓘ
Return a blocking stream of Bytes objects containing the file content.