FileReader

Struct FileReader 

pub struct FileReader { /* private fields */ }

Implementations

Source

impl FileReader

pub fn file_length(&self) -> usize

Returns the total size of the file

pub fn remaining(&self) -> usize

Returns the remaining bytes left based on the current cursor position.

pub fn set_position(&mut self, pos: usize)

Sets the cursor to the position. Panics if the position is beyond the end of the file

pub fn tell(&self) -> usize

Returns the current cursor position in the file

pub async fn read_bytes(&mut self, len: usize) -> Result<Bytes>

Read up to len bytes into a new Bytes object, advancing the internal position in the file. An empty Bytes object will be returned if the end of the file has been reached.

pub async fn read_into(&mut self, buf: &mut [u8]) -> Result<usize>

Read up to buf.len() bytes into the provided slice, advancing the internal position in the file. Returns the number of bytes that were read, or 0 if the end of the file has been reached.

pub async fn read_range(&self, offset: usize, len: usize) -> Result<Bytes>

Read up to len bytes starting at offset into a new Bytes object. The returned buffer could be smaller than len if offset + len extends beyond the end of the file.

Panics if the requested range is outside of the file

pub async fn read_range_buf(&self, buf: &mut [u8], offset: usize) -> Result<()>

Read file data into an existing buffer

Panics if the requested range is outside of the file

pub fn read_range_stream( &self, offset: usize, len: usize, ) -> impl Stream<Item = Result<Bytes>> + use<>

Return a stream of Bytes objects containing the content of the file

Panics if the requested range is outside of the file